@@ -43,7 +43,7 @@ REPL.prototype.loadForm = function () {
     form.append(prompt_input);
 
     var input = $('<input type="text" name="source" class="repl-input" />');
-    input.attr('size', '68');
+    input.attr('size', '67');
     input.attr('autocomplete', 'off');
     var repl = this;
 
@@ -117,7 +117,7 @@ REPL.prototype.showLine = function (output, prompt) {
     $(line).append(pre).appendTo(this.outputNode);
 
     // auto scroll
-    this.parent.parentNode.scrollTop = this.parent.parentNode.scrollHeight - this.parent.parentNode.offsetHeight;
+    this.parent.parentNode.scrollTop = this.parent.parentNode.scrollHeight - this.parent.parentNode.offsetHeight + 30;
 }
 
 REPL.prototype.process = function (event) {
